populacao_padrao: Retrieve ready-made standard populations

View source: R/indicators.R

populacao_padraoR Documentation

Retrieve ready-made standard populations

Description

Returns age-group weights for the WHO 2000–2025 world standard, Segi's world standard or the Scandinavian standard. By default weights are normalized to sum to one and can be passed directly to [padronizar_idade()].

Usage

populacao_padrao(
  nome = "oms_2000_2025",
  formato = c("vetor", "dados"),
  normalizar = TRUE
)

Arguments

nome

Standard population: '"oms_2000_2025"', '"segi"' or '"escandinava"'. '"oms"' and '"who"' are accepted aliases.

formato

Output as a named numeric '"vetor"' or a data frame ('"dados"').

normalizar

Whether weights should be normalized to sum to one.

Value

A named numeric vector or a data frame with 'faixa_etaria', 'peso_publicado' and 'peso'.

References

Ahmad OB et al. (2001). Age standardization of rates: a new WHO standard. https://cdn.who.int/media/docs/default-source/gho-documents/global-health-estimates/gpe_discussion_paper_series_paper31_2001_age_standardization_rates.pdf

Examples

populacao_padrao("oms")
populacao_padrao("segi", formato = "dados")

datasus documentation built on Oct. 7, 2026, 1:07 a.m.