sim_inf10_uf: Scrapes SIM's ICD-10 child mortality data from ufs

View source: R/sim_inf10_uf.R

sim_inf10_ufR Documentation

Scrapes SIM's ICD-10 child mortality data from ufs

Description

This function allows the user to retrive data from SIM's ICD-10 database much in the same way that is done by the online portal. The argument options refer to child mortality data from the states unities.

Usage

sim_inf10_uf(uf, linha = "Município", coluna = "Não ativa",
  conteudo = 1, periodo = "last", municipio = "all", cir = "all",
  macrorregiao_de_saude = "all", divisao_admnist_estadual = "all",
  microrregiao_ibge = "all", ride = "all", capitulo_cid10 = "all",
  categoria_cid10 = "all", lista_mort_cid10 = "all",
  causa_mal_definidas = "all", faixa_etaria_1 = "all",
  faixa_etaria_2 = "all", faixa_etaria_3 = "all", faixa_etaria_4 = "all",
  faixa_etaria_5 = "all", faixa_etaria_detalhada = "all",
  sexo = "all", cor_raca = "all", local_ocorrencia = "all",
  idade_mae = "all", escolaridade_mae = "all",
  duracao_gestacao = "all", tipo_gravidez = "all", tipo_parto = "all",
  peso_ao_nascer = "all", obito_relacao_parto = "all",
  obito_investigado = "all")

Arguments

uf

A character of length = 1 with the state"all".

linha

A character describing which element will be displayed in the rows of the data.frame. Defaults to "Município".

coluna

A character describing which element will be displayed in the columns of the data.frame. Defaults to "Não ativa".

conteudo

A character of length = 1 with the state's acronym of interest.

periodo

A character vector describing the period of data. Defaults to the last available.

municipio

"all" or a numeric vector with the IBGE's city codes codes to filter the data. Defaults to "all".

cir

"all" or a numeric vector with the CIR's codes to filter the data. Defaults to "all".

macrorregiao_de_saude

"all" or a numeric vector with the Health macro-region's codes to filter the data. Defaults to "all".

divisao_admnist_estadual

"all" or a numeric vector with the State administrative division's codes to filter the data. Defaults to "all".

microrregiao_ibge

"all" or a numeric vector with the IBGE's micro-region codes to filter the data. Defaults to "all".

ride

"all" or a numeric vector with the IBGE's metropolitan-region codes to filter the data. Defaults to "all".

capitulo_cid10

"all" or a numeric vector with the ICD-10 chapter to filter the data. Defaults to "all".

categoria_cid10

"all" or a character vector with the ICD-10 category codes (capital letter and two numbers) to filter the data. Defaults to "all".

lista_mort_cid10

"all" or a character vector with the mortality type (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

causa_mal_definidas

"all" or a character vector with the ill-defined causes (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

faixa_etaria_1

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

faixa_etaria_2

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

faixa_etaria_3

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

faixa_etaria_4

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

faixa_etaria_5

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

faixa_etaria_detalhada

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

sexo

"all" or a character vector with the gender (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

cor_raca

"all" or a character vector with the color/race (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

local_ocorrencia

"all" or a character vector with the place of ocurrence to filter the data. Defaults to "all".

idade_mae

"all" or a character vector with the age range (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

escolaridade_mae

"all" or a character vector with the mother's instruction (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

duracao_gestacao

"all" or a character vector with the marital status of the mother (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

tipo_gravidez

"all" or a character vector with the type of pregnancy (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

tipo_parto

"all" or a character vector with the Parturition type (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

peso_ao_nascer

"all" or a character vector with the birth weight (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

obito_relacao_parto

"all" or a character vector with period of child mortality in relation to childbirth (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

obito_investigado

"all" or a character vector indicating if the death was investigated (written in the same way) or the number corresponding to the order of the option in the online layout to filter the data. Defaults to "all".

Value

The function returns a data frame printed by parameters input.

Lifecycle

This function is deprecated. Use 'sim()' or 'sinasc()' with a named 'filtros' list. The legacy signature is retained for compatibility.

Author(s)

Renato Prado Siqueira rpradosiqueira@gmail.com

See Also

sim_evita10_uf

Examples


old_options <- options(
  datasus.timeout = 5,
  datasus.download_timeout = 15,
  datasus.max_tries = 1
)
try({
## Requesting data from the state of Mato Grosso do Sul
sim_inf10_uf(uf = "ms")
})
options(old_options)



datasus documentation built on Oct. 7, 2026, 1:07 a.m.