siscan: Query cancer screening and diagnostic exams from SISCAN

View source: R/health-services.R

siscanR Documentation

Query cancer screening and diagnostic exams from SISCAN

Description

Supports cervical cytology and histology, mammography, and breast cytology and histology by residence, attendance location or patient.

Usage

siscan(
  conjunto = "citologia_colo_residencia",
  uf = NULL,
  linha = NULL,
  coluna = NULL,
  conteudo = 1,
  periodo = "last",
  filtros = list()
)

Arguments

conjunto

Dataset name listed by 'datasus_catalogo("sih")'.

uf

Two-letter state abbreviation. 'NULL' uses the Brazil form.

linha

Row dimension. ‘NULL' selects the form’s first dimension.

coluna

Column dimension. 'NULL' selects '"Não ativa"'.

conteudo

Measure label, raw TABNET value, or one-based index.

periodo

'"last"' for the latest competence, an exact period label or raw value, a four-digit year (all available competences in that year), or a vector of these values.

filtros

Named list of filters. Names and choices are available from [datasus_opcoes()].

Value

A data frame containing the TABNET result.

Examples


old_options <- options(
  datasus.timeout = 5,
  datasus.download_timeout = 15,
  datasus.max_tries = 1
)
try({
siscan(uf = "MS")
siscan(
  conjunto = "mamografia_residencia",
  uf = "MS",
  periodo = 2025
)
})
options(old_options)


datasus documentation built on Oct. 7, 2026, 1:07 a.m.