View source: R/health-services.R
| cnes | R Documentation |
Supports establishments, physical resources, human resources and health teams. Use 'datasus_catalogo("cnes")' to list the available datasets.
cnes(
conjunto = "estabelecimentos",
uf = NULL,
linha = NULL,
coluna = NULL,
conteudo = 1,
periodo = "last",
filtros = list()
)
conjunto |
Dataset name listed by 'datasus_catalogo("sih")'. |
uf |
Two-letter state abbreviation. 'NULL' uses the Brazil form. |
linha |
Row dimension. ‘NULL' selects the form’s first dimension. |
coluna |
Column dimension. 'NULL' selects '"Não ativa"'. |
conteudo |
Measure label, raw TABNET value, or one-based index. |
periodo |
'"last"' for the latest competence, an exact period label or raw value, a four-digit year (all available competences in that year), or a vector of these values. |
filtros |
Named list of filters. Names and choices are available from [datasus_opcoes()]. |
A data frame containing the TABNET result.
old_options <- options(
datasus.timeout = 5,
datasus.download_timeout = 15,
datasus.max_tries = 1
)
try({
cnes(uf = "MS")
cnes(
conjunto = "leitos_internacao",
uf = "MS",
periodo = "last"
)
})
options(old_options)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.