| datasus_dicionario | R Documentation |
Returns the fields currently standardized by [datasus_padronizar()]. Contemporary schemas cover the variables documented in the official ESAVI, e-SUS Notifica, PNI and hospital-occupancy dictionaries. Fields added by a source after the packaged dictionary was released remain untouched and can be detected with [datasus_validar_esquema()].
datasus_dicionario(sistema, tipo = NULL)
sistema |
System: '"sim"', '"sinasc"', '"sih"', '"esavi"', '"sindrome_gripal"', '"pni_doses"' or '"ocupacao_hospitalar"'. |
tipo |
Optional raw file type. 'NULL' selects the default type. |
A data frame with original field, standardized field, description, target class and date format.
datasus_dicionario("sim")
datasus_dicionario("sih", "RD")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.