View source: R/health-services.R
| populacao_residente | R Documentation |
Provides census, projection, retroprojection and municipal estimate datasets published in the DATASUS population section. The default dataset contains municipal estimates by sex and age from 2000 through 2021.
populacao_residente(
conjunto = "estimativa_municipal",
uf = NULL,
linha = NULL,
coluna = NULL,
conteudo = 1,
periodo = "last",
filtros = list()
)
conjunto |
Dataset name listed by 'datasus_catalogo("sih")'. |
uf |
Two-letter state abbreviation. 'NULL' uses the Brazil form. |
linha |
Row dimension. ‘NULL' selects the form’s first dimension. |
coluna |
Column dimension. 'NULL' selects '"Não ativa"'. |
conteudo |
Measure label, raw TABNET value, or one-based index. |
periodo |
'"last"' for the latest competence, an exact period label or raw value, a four-digit year (all available competences in that year), or a vector of these values. |
filtros |
Named list of filters. Names and choices are available from [datasus_opcoes()]. |
A data frame containing the TABNET result.
old_options <- options(
datasus.timeout = 5,
datasus.download_timeout = 15,
datasus.max_tries = 1
)
try({
populacao_residente(uf = "MS", periodo = 2021)
populacao_residente(
linha = "Unidade da Federação",
periodo = c(2020, 2021)
)
})
options(old_options)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.